@@ -13,9 +13,13 @@ class ErrorCodes(object):
     class Address(object):
         CannotBeBlank = "81801"
         CompanyIsTooLong = "81802"
+        CountryCodeAlpha2IsNotAccepted = "91814"
+        CountryCodeAlpha3IsNotAccepted = "91816"
+        CountryCodeNumericIsNotAccepted = "91817"
         CountryNameIsNotAccepted = "91803"
         ExtedAddressIsTooLong = "81804"
         FirstNameIsTooLong = "81805"
+        InconsistentCountry = "91815"
         LastNameIsTooLong = "81806"
         LocalityIsTooLong = "81807"
         PostalCodeInvalidCharacters = "81813"
@@ -60,18 +64,19 @@ class ErrorCodes(object):
         CustomFieldIsInvalid = "91602"
         CustomFieldIsTooLong = "81603"
         EmailIsInvalid = "81604"
-        EmailIsTooLong = "81605"
         EmailIsRequired = "81606"
+        EmailIsTooLong = "81605"
         FaxIsTooLong = "81607"
         FirstNameIsTooLong = "81608"
         IdIsInUse = "91609"
         IdIsInvaild = "91610"
         IdIsNotAllowed = "91611"
+        IdIsRequired = "91613"
         IdIsTooLong = "91612"
         LastNameIsTooLong = "81613"
         PhoneIsTooLong = "81614"
-        WebsiteIsTooLong = "81615"
         WebsiteIsInvalid = "81616"
+        WebsiteIsTooLong = "81615"
 
     class Subscription(object):
         CannotEditCanceledSubscription = "81901"
